@@ -93,6 +93,13 @@ def param_to_jslink(model, widget):
     from ..widgets import LiteralInput, Widget
 
     param_pane = widget._param_pane
+
+    # If param_pane is a class (not an instance), it means the widget was created
+    # via Widget.from_param() as a class method. In this case, we cannot access
+    # instance attributes like _widgets, so we skip JS link conversion.
+    if isinstance(param_pane, type):
+        return
+
     pobj = param_pane.object
     pname = [k for k, v in param_pane._widgets.items() if v is widget]
     watchers = [
@@ -188,8 +195,8 @@ def embed_state(panel, model, doc, max_states=1000, max_opts=3,
     be replayed when exported. The state is recorded on a State model
     which is attached as an additional root on the Document.
 
-    Arguments
-    ---------
+    Parameters
+    ----------
     panel: panel.reactive.Reactive
       The Reactive component being exported
     model: bokeh.model.Model
@@ -319,12 +326,12 @@ def embed_state(panel, model, doc, max_states=1000, max_opts=3,
     if len(cross_product) > max_states:
         if config._doc_build:
             return
-        param.main.param.warning('The cross product of different application '
-                           'states is very large to explore (N=%d), consider '
-                           'reducing the number of options on the widgets or '
-                           'increase the max_states specified in the function '
-                           'to remove this warning' %
-                           len(cross_product))
+        param.main.param.warning(
+            'The cross product of different application states is very large '
+            f'to explore (N={len(cross_product)}), consider reducing the number '
+            'of options on the widgets or increase the max_states specified '
+            'in the function to remove this warning.'
+        )
 
     nested_dict = lambda: defaultdict(nested_dict)
     state_dict = nested_dict()
