@@ -1,4 +1,5 @@
 import {div, px} from "@bokehjs/core/dom"
+import type {DOMView} from "@bokehjs/core/dom_view"
 import {isArray} from "@bokehjs/core/util/types"
 import {unreachable} from "@bokehjs/core/util/assert"
 import {WidgetView} from "@bokehjs/models/widgets/widget"
@@ -54,6 +55,17 @@ export class PanelMarkupView extends WidgetView {
     }
   }
 
+  rerender_(view: DOMView | null = null): void {
+    // Can be removed when Bokeh>3.7 (see https://github.com/holoviz/panel/pull/7815)
+    view = view == null ? this : view
+    if (view.rerender) {
+      view.rerender()
+    } else {
+      view.render()
+      view.r_after_render()
+    }
+  }
+
   style_redraw(): void {}
 
   has_math_disabled(): boolean {
@@ -103,6 +115,9 @@ export function set_size(el: HTMLElement, model: HTMLBox, adjust_margin: boolean
           height_policy = "max"
           break
         }
+        case "inherit": {
+          break
+        }
         default: {
           unreachable()
         }
@@ -169,6 +184,17 @@ export abstract class HTMLBoxView extends LayoutDOMView {
     set_size(this.el, this.model)
   }
 
+  rerender_(view: DOMView | null = null): void {
+    // Can be removed when Bokeh>3.7 (see https://github.com/holoviz/panel/pull/7815)
+    view = view == null ? this : view
+    if (view.rerender) {
+      view.rerender()
+    } else {
+      view.render()
+      view.r_after_render()
+    }
+  }
+
   watch_stylesheets(): void {
     this._initialized_stylesheets = new Map()
     for (const stylesheet of this._applied_stylesheets) {
