@@ -3,20 +3,27 @@ try:
 except ImportError:
     hv = None
 
+import param
 import pytest
 
 from bokeh.plotting import figure
 
+from panel.custom import JSComponent
 from panel.layout import Row
-from panel.links import Link
+from panel.links import Callback, Link
 from panel.pane import Bokeh, HoloViews
 from panel.tests.util import hv_available
 from panel.widgets import (
-    ColorPicker, DatetimeInput, FloatInput, FloatSlider, RangeSlider,
+    Button, ColorPicker, DatetimeInput, FloatInput, FloatSlider, RangeSlider,
     TextInput,
 )
 
 
+class MockJSComponent(JSComponent):
+
+    value = param.Parameter()
+
+
 def test_widget_link_bidirectional():
     t1 = TextInput()
     t2 = TextInput()
@@ -31,7 +38,6 @@ def test_widget_link_bidirectional():
     assert t1.value == 'DEF'
     assert t2.value == 'DEF'
 
-
 def test_widget_jslink_bidirectional(document, comm):
     t1 = TextInput()
     t2 = TextInput()
@@ -44,14 +50,53 @@ def test_widget_jslink_bidirectional(document, comm):
 
     tm1, tm2 = model.children
 
-    link1_customjs = tm1.js_property_callbacks['change:value'][-1]
-    link2_customjs = tm2.js_property_callbacks['change:value'][-1]
+    callbacks1 = tm1.js_property_callbacks['change:value']
+    callbacks2 = tm2.js_property_callbacks['change:value']
+    assert len(callbacks1) == 1
+    assert len(callbacks2) == 1
+
+    link1_customjs = callbacks1[0]
+    link2_customjs = callbacks2[0]
 
     assert link1_customjs.args['source'] is tm1
     assert link2_customjs.args['source'] is tm2
     assert link1_customjs.args['target'] is tm2
     assert link2_customjs.args['target'] is tm1
 
+    row[:] = row[::-1]
+
+    assert len(callbacks1) == 1
+    assert len(callbacks2) == 1
+
+def test_widget_link_bidirectional_esm(document, comm):
+    t1 = TextInput()
+    t2 = MockJSComponent()
+
+    t1.jslink(t2, value='value', bidirectional=True)
+
+    row = Row(t1, t2)
+
+    model = row.get_root(document, comm)
+
+    tm1, tm2 = model.children
+
+    callbacks1 = tm1.js_property_callbacks['change:value']
+    callbacks2 = tm2.data.js_property_callbacks['change:value']
+    assert len(callbacks1) == 1
+    assert len(callbacks2) == 1
+
+    link1_customjs = callbacks1[0]
+    link2_customjs = callbacks2[0]
+
+    assert link1_customjs.args['source'] is tm1
+    assert link2_customjs.args['source'] is tm2.data
+    assert link1_customjs.args['target'] is tm2.data
+    assert link2_customjs.args['target'] is tm1
+
+    row[:] = row[::-1]
+
+    assert len(callbacks1) == 1
+    assert len(callbacks2) == 1
 
 def test_widget_link_source_param_not_found():
     t1 = TextInput()
@@ -353,3 +398,33 @@ def test_link_with_customcode(document, comm):
     assert link_customjs.args['source'] is range_slider
     assert link_customjs.args['x_range'] is x_range
     assert link_customjs.code == f"try {{ {code} }} catch(err) {{ console.log(err) }}"
+
+
+def test_callback_unwatch():
+    button = Button(name="Test")
+    cb = button.js_on_click(args=dict(url="google.com"), code="window.open(url, '_blank');")
+
+    assert len(Callback.registry.get(button, [])) == 1
+    assert cb in Callback.registry[button]
+
+    cb.unwatch()
+
+    assert len(Callback.registry.get(button, [])) == 0
+
+
+def test_callback_unwatch_multiple_callbacks():
+    button = Button(name="Test")
+    cb1 = button.js_on_click(args=dict(url1="url1"), code="console.log('1');")
+    cb2 = button.js_on_click(args=dict(url2="url2"), code="console.log('2');")
+
+    assert len(Callback.registry.get(button, [])) == 2
+
+    cb1.unwatch()
+
+    assert len(Callback.registry.get(button, [])) == 1
+    assert cb1 not in Callback.registry[button]
+    assert cb2 in Callback.registry[button]
+
+    cb2.unwatch()
+
+    assert len(Callback.registry.get(button, [])) == 0
